#
# spec file for package ghc-tasty
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name tasty
%global pkgver %{pkg_name}-%{version}
Name:           ghc-%{pkg_name}
Version:        1.5
Release:        1.3
Summary:        Modern and extensible testing framework
License:        MIT
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
Source1:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/revision/1.cabal#/%{pkg_name}.cabal
# https://github.com/UnkindPartition/tasty/pull/371
Patch0:         riscv64-unbounded-delays.patch
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-ansi-terminal-devel
BuildRequires:  ghc-ansi-terminal-prof
BuildRequires:  ghc-base-devel
BuildRequires:  ghc-base-prof
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-containers-prof
BuildRequires:  ghc-optparse-applicative-devel
BuildRequires:  ghc-optparse-applicative-prof
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-stm-devel
BuildRequires:  ghc-stm-prof
BuildRequires:  ghc-tagged-devel
BuildRequires:  ghc-tagged-prof
BuildRequires:  ghc-transformers-devel
BuildRequires:  ghc-transformers-prof
BuildRequires:  ghc-unix-devel
BuildRequires:  ghc-unix-prof
ExcludeArch:    %{ix86}

%description
Tasty is a modern testing framework for Haskell. It lets you combine your unit
tests, golden tests, QuickCheck/SmallCheck properties, and any other types of
tests into a single test suite.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%package -n ghc-%{pkg_name}-doc
Summary:        Haskell %{pkg_name} library documentation
Requires:       ghc-filesystem
BuildArch:      noarch

%description -n ghc-%{pkg_name}-doc
This package provides the Haskell %{pkg_name} library documentation.

%package -n ghc-%{pkg_name}-prof
Summary:        Haskell %{pkg_name} profiling library
Requires:       ghc-%{pkg_name}-devel = %{version}-%{release}
Supplements:    (ghc-%{pkg_name}-devel and ghc-prof)

%description -n ghc-%{pkg_name}-prof
This package provides the Haskell %{pkg_name} profiling library.

%prep
%setup -q -n %{pkg_name}-%{version}
tr -d '\r' <%{SOURCE1} >%{pkg_name}.cabal
%autopatch -p0

%build
%ghc_lib_build

%install
%ghc_lib_install

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc CHANGELOG.md README.md

%files -n ghc-%{pkg_name}-doc -f ghc-%{pkg_name}-doc.files
%license LICENSE

%files -n ghc-%{pkg_name}-prof -f ghc-%{pkg_name}-prof.files

%changelog
* Wed Sep 27 2023 Peter Simons <psimons@suse.com>
- Update tasty to version 1.5 revision 1.
  Version 1.5
  - --------------
  _2023-09-10_
  * Progress reporting is no longer ignored.
    `PrintTest` constructor of `TestOutput` now has an extra field used to report progress.
    Supply `const (pure ())` as this extra field value if you want to skip progress reporting
    ([#311](https://github.com/UnkindPartition/tasty/pull/311)).
  * `foldGroup` now takes `[b]` instead of `b` as its last argument to allow
    for custom fold strategies. This is a backwards incompatible change,
    but you can get the old behavior by applying `mconcat`
    ([#364](https://github.com/UnkindPartition/tasty/issues/364)).
  * Dependency loop error now lists all test cases that formed a cycle
    ([#340](https://github.com/UnkindPartition/tasty/issues/340)).
  * Dependencies can now be defined pattern-free with `sequentialTestGroup`
    ([#343](https://github.com/UnkindPartition/tasty/issues/343)).
  * Added `--min-duration-to-report` flag that specifies the time a test
    must take before `tasty` outputs timing information
    ([#341](https://github.com/UnkindPartition/tasty/issues/341)).
  * When a test failed with an exception, print it using `displayException`
    instead of `show`
    ([#330](https://github.com/UnkindPartition/tasty/issues/330)).
  * The `-p` / `--pattern` option can be specified multiple times;
    only tests that match all patterns are run
    ([#380](https://github.com/UnkindPartition/tasty/pull/380)).
  * Fix color scheme to make info messages visible in terminals with white background
    ([#369](https://github.com/UnkindPartition/tasty/pull/369)).
  * When parsing of a command-line option failed, report received option
    ([#368](https://github.com/UnkindPartition/tasty/pull/368)).
  * Support WASM
    ([#365](https://github.com/UnkindPartition/tasty/pull/365)).
  * Tested with GHC 8.0 - 9.8.
* Wed Aug  2 2023 Andreas Schwab <schwab@suse.de>
- riscv64-unbounded-delays.patch: Don't depend on unbounded-delays for
  riscv64
* Thu Mar 30 2023 Peter Simons <psimons@suse.com>
- Updated spec file to conform with ghc-rpm-macros-2.5.2.
* Sun Dec 18 2022 Peter Simons <psimons@suse.com>
- Update tasty to version 1.4.3.
  Upstream has edited the change log file since the last release in
  a non-trivial way, i.e. they did more than just add a new entry
  at the top. You can review the file at:
  http://hackage.haskell.org/package/tasty-1.4.3/src/CHANGELOG.md
* Sat May  7 2022 Peter Simons <psimons@suse.com>
- Update tasty to version 1.3.1 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Tue Aug 18 2020 Peter Simons <psimons@suse.com>
- Replace %%setup -q with the more modern %%autosetup macro.
* Tue Jun  9 2020 psimons@suse.com
- Add tasty at version 1.3.1.
